/* Pango
 * pango-context.c: Contexts for itemization and shaping
 *
 * Copyright (C) 2000 Red Hat Software
 * Copyright (C) 2003 Sun Microsystems
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include "pango/pango-context-private.h"
#include "pango/pangogp-context.h"
#include "pango/pangogp-private.h"

struct _PangoGPContext
{
  PangoContext       parent_instance;

  PangoGPDebugFlags  debug_flags;

  GnomePrintContext *gpc;
};

struct _PangoGPContextClass
{
  PangoContextClass        parent_class;
};

static void pango_gp_context_class_init  (PangoGPContextClass *klass);

static gpointer parent_class;

GType
pango_gp_context_get_type (void)
{
  static GType object_type = 0;

  if (!object_type)
    {
      static const GTypeInfo object_info =
      {
        sizeof (PangoGPContextClass),
        (GBaseInitFunc) NULL,
        (GBaseFinalizeFunc) NULL,
        (GClassInitFunc) pango_gp_context_class_init,
        NULL,           /* class_finalize */
        NULL,           /* class_data */
        sizeof (PangoGPContext),
        0,              /* n_preallocs */
	NULL,
	NULL
      };
      
      object_type = g_type_register_static (PANGO_TYPE_CONTEXT,
                                            "PangoGPContext",
                                            &object_info, 0);
    }
  
  return object_type;
}

static void
pango_gp_context_class_init (PangoGPContextClass *klass)
{
  parent_class = g_type_class_peek_parent (klass);

  PANGO_CONTEXT_CLASS (klass)->layout_new = pango_gp_layout_new;
}

/**
 * pango_gp_context_new:
 * 
 * Creates a new #PangoGPContext initialized to default value.
 * 
 * Return value: the new #PangoGPContext.
 **/
PangoContext *
pango_gp_context_new (void)
{
  PangoContext *context;

  context =
    PANGO_CONTEXT (g_object_new (pango_gp_context_get_type (),
				 NULL));
  
  return context;
}

PangoGPDebugFlags
pango_gp_context_get_debug_flags (PangoContext *context)
{
  g_return_val_if_fail (PANGO_IS_GP_CONTEXT (context),
			PANGO_GP_DEBUG_NONE);

  return (PANGO_GP_CONTEXT (context)->debug_flags);
}

void
pango_gp_context_set_debug_flags (PangoContext         *context,
				  PangoGPDebugFlags debug_flags)
{
  g_return_if_fail (PANGO_IS_GP_CONTEXT (context));

  PANGO_GP_CONTEXT (context)->debug_flags = debug_flags;
}

GnomePrintContext *
pango_gp_context_get_context (PangoContext *context)
{
  g_return_val_if_fail (PANGO_IS_GP_CONTEXT (context),
			NULL);

  return (PANGO_GP_CONTEXT (context)->gpc);
}

void
pango_gp_context_set_context (PangoContext      *context,
			      GnomePrintContext *gpc)
{
  g_return_if_fail (PANGO_IS_GP_CONTEXT (context));

  PANGO_GP_CONTEXT (context)->gpc = gpc;
}
